
.. py:currentmodule:: pythreejs

GridHelper
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: GridHelper(size=10, divisions=10, colorCenterLine="0x444444", colorGrid="0x888888", )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Object3D`.

    Three.js docs: https://threejs.org/docs/#api/helpers/GridHelper


    .. py:attribute:: size

        .. sourcecode:: python

            CFloat(10, allow_none=False).tag(sync=True)

    .. py:attribute:: divisions

        .. sourcecode:: python

            CInt(10, allow_none=False).tag(sync=True)

    .. py:attribute:: colorCenterLine

        .. sourcecode:: python

            Unicode("0x444444", allow_none=False).tag(sync=True)

    .. py:attribute:: colorGrid

        .. sourcecode:: python

            Unicode("0x888888", allow_none=False).tag(sync=True)

